/*
 *  Copyright (C) 2000 Lyrisoft Solutions, Inc.
 *
 *  This library is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Library General Public License as published
 *  by the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package com.lyrisoft.sql;

import java.util.Collection;
import java.util.List;
import java.util.LinkedList;
import java.util.HashSet;
import java.util.Iterator;

/**
 * Represents a Node in a dependency graph of tables
 */
public class Node {
    public HashSet _imports;
    public String _name;

    /**
     * @param name the name of the table
     */
    public Node(String name) {
        _imports = new HashSet();
        _name = name;
    }
    
    public String getName() {
        return _name;
    }
    
    /**
     * add a dependency to another node
     */
    public void addDependency(Node node) {
        _imports.add(node);
    }

    /**
     * get all the dependencies as a Collection
     */
    public Collection getDependencies() {
        return new LinkedList(_imports);
    }

    /**
     * get all my dependencies and the dependencies of my dependencies recursively
     * (warning: there might be a chance for an infinite loop here....)
     */
    public Collection getDeepDependencies() {
        HashSet allImports = new HashSet(_imports);
        for (Iterator i = _imports.iterator(); i.hasNext(); ) {
            Node n = (Node)i.next();
            allImports.addAll(n.getDeepDependencies());
        }
        return allImports;
    }

    public boolean equals(Object o) {
        return ((Node)o)._name.equals(_name);
    }

    public int hashCode() {
        return _name.hashCode();
    }

    public String toString() {
        return _name;
    }
}
